pub enum FinishError {
Incomplete {
elapsed: Duration,
source: CompletionError,
},
Terminal(TerminalError),
}Expand description
Failure from checked finish after the operation has been consumed.
Variants
Incomplete
Completion validation failed before terminal emission.
Fields

source: CompletionErrorFirst completion invariant that failed.
Terminal(TerminalError)
A terminal emission was attempted and failed permanently.
Implementations
Sourceimpl FinishError
impl FinishError
Sourcepub const fn elapsed(&self) -> Duration
pub const fn elapsed(&self) -> Duration
Returns elapsed operation time sampled by the finish attempt.
Sourcepub const fn completion_error(&self) -> Option<&CompletionError>
pub const fn completion_error(&self) -> Option<&CompletionError>
Returns the completion error when validation failed.