pub enum RecoverableFinishError<'reporter> {
Incomplete {
progress: Progress<'reporter>,
source: CompletionError,
},
Terminal(TerminalError),
}Expand description
Failure from checked finish while preserving a reusable progress operation.
Variants
Incomplete
Completion validation failed and the operation remains reusable.
Fields

source: CompletionErrorFirst completion invariant that failed.
Terminal(TerminalError)
A terminal emission was attempted and failed permanently.
Implementations
Sourceimpl<'reporter> RecoverableFinishError<'reporter>
impl<'reporter> RecoverableFinishError<'reporter>
Sourcepub fn completion_error(&self) -> Option<&CompletionError>
pub fn completion_error(&self) -> Option<&CompletionError>
Returns the completion error when validation failed.
Sourcepub fn into_progress(self) -> Result<Progress<'reporter>, TerminalError>
pub fn into_progress(self) -> Result<Progress<'reporter>, TerminalError>
Consumes an incomplete finish error and returns the reusable Progress.
Sourcepub fn into_parts(
self,
) -> Result<(Progress<'reporter>, CompletionError), TerminalError>
pub fn into_parts( self, ) -> Result<(Progress<'reporter>, CompletionError), TerminalError>
Consumes this error and returns its recoverable or terminal parts.