Module reporter

Module reporter 

Progress reporter trait and built-in implementations.

Re-exports

pub use format::HumanReadableMetricSnapshotFormatter;
pub use format::JsonMetricSnapshotFormatter;
pub use format::MetricSnapshotFormatter;

Modules

format
Formatting support for progress metric snapshots.

Structs

FormattedProgressReporter
Progress reporter that formats each metric snapshot and sends it to a consumer.
HumanReadableProgressReporter
Progress reporter that emits human-readable strings to a consumer.
JsonLoggerProgressReporter
Progress reporter that emits JSON metric snapshots through log.
JsonProgressReporter
Progress reporter that emits JSON metric snapshot strings to a consumer.
JsonStderrProgressReporter
Progress reporter that writes JSON metric snapshots to stderr.
JsonStdoutProgressReporter
Progress reporter that writes JSON metric snapshots to stdout.
JsonWriterProgressReporter
Progress reporter that writes JSON metric snapshots to a writer.
LoggerProgressReporter
Progress reporter that emits human-readable metric snapshots through log.
MetricSnapshotProgressReporter
Progress reporter that sends metric snapshot objects to a consumer.
NoOpProgressReporter
Progress reporter that ignores all events.
StderrProgressReporter
Progress reporter that writes human-readable metric snapshots to stderr.
StdoutProgressReporter
Progress reporter that writes human-readable metric snapshots to stdout.
WriterProgressReporter
Progress reporter that writes human-readable metric snapshots to a writer.

Traits

ProgressReporter
Receives immutable progress events for one logical operation.