pub struct MetricSnapshotProgressReporter<C = ArcConsumer<ProgressMetricSnapshot>> { /* private fields */ }Expand description
Progress reporter that sends metric snapshot objects to a consumer.
This reporter is useful for GUI, database, metrics, and monitoring adapters that want structured metric snapshots instead of preformatted strings.
Implementations
Sourceimpl<C> MetricSnapshotProgressReporter<C>
impl<C> MetricSnapshotProgressReporter<C>