Module running

Module running 

Helpers for running progress reporting loops.

Running Progress

Provides helpers for reporting running progress from a separate loop.

Author

Haixing Hu

Structs

RunningProgressLoop
Runs periodic running progress reports for work tracked elsewhere.
RunningProgressNotifier
Notifies a RunningProgressLoop about progress points and completion.
RunningProgressPoints
Worker-side handle for reporting running progress points.
ScopedRunningProgress
Owns a scoped running progress reporter thread.