AutoReporter

Struct AutoReporter 

pub struct AutoReporter<'scope, 'reporter> { /* private fields */ }
Handle controlling one scoped automatic reporter.

Implementations

Source

impl<'scope, 'reporter> AutoReporter<'scope, 'reporter>

pub fn notifier(&self) -> ProgressNotifier

Returns a cloneable worker notification handle.

pub fn status(&self) -> AutoReporterStatus

Returns a cloneable status view for workers.

pub fn stop(self) -> Result<(), AutoReporterError>

Stops, joins and returns the background report result.

A reporter or snapshot error is returned as AutoReporterError::Emission. A worker panic is captured as AutoReporterError::Panicked after the worker has been joined.

Errors

Returns a reporter emission failure or a structured worker panic.