pub struct DeliveryError { /* private fields */ }Expand description
Failure while delivering one complete Event to a reporter.
Implementations
Sourceimpl DeliveryError
impl DeliveryError
Sourcepub const fn reporter_error(&self) -> &ReporterError
pub const fn reporter_error(&self) -> &ReporterError
Returns the original reporter error.
Sourcepub fn into_event(self) -> Event
pub fn into_event(self) -> Event
Consumes the error and returns its failed Event.
Sourcepub fn into_reporter_error(self) -> ReporterError
pub fn into_reporter_error(self) -> ReporterError
Consumes the error and returns its reporter error.
Sourcepub fn into_parts(self) -> (Event, ReporterError)
pub fn into_parts(self) -> (Event, ReporterError)
Consumes the error and returns the Event with its reporter error.