pub struct MetricDelta { /* private fields */ }Expand description
One atomic batch of additive metric lifecycle changes.
Implementations
Sourceimpl MetricDelta
impl MetricDelta
Sourcepub const fn started(self, count: u64) -> Self
pub const fn started(self, count: u64) -> Self
Sets the number of work items entering the active state.
Sourcepub const fn unclassified(self, count: u64) -> Self
pub const fn unclassified(self, count: u64) -> Self
Sets the number of work items completing without classification.
Sourcepub const fn succeeded(self, count: u64) -> Self
pub const fn succeeded(self, count: u64) -> Self
Sets the number of work items completing successfully.