pub struct ProgressBuilder<'reporter> { /* private fields */ }Expand description
Configures one Progress operation before it starts.
Implementations
Sourceimpl<'reporter> ProgressBuilder<'reporter>
impl<'reporter> ProgressBuilder<'reporter>
Sourcepub const fn interval(self, interval: Duration) -> Self
pub const fn interval(self, interval: Duration) -> Self
Sets the minimum interval between due-based running reports.
Sourcepub fn stage(self, stage: Stage) -> Self
pub fn stage(self, stage: Stage) -> Self
Adds stage metadata to the Started event and subsequent events.
Sourcepub fn attribute(self, key: &str, value: &str) -> Self
pub fn attribute(self, key: &str, value: &str) -> Self
Adds or replaces one operation correlation attribute.
Sourcepub fn attributes(self, attributes: OperationAttributes) -> Self
pub fn attributes(self, attributes: OperationAttributes) -> Self
Replaces all operation correlation attributes.
Sourcepub fn start(self) -> Result<Progress<'reporter>, StartError>
pub fn start(self) -> Result<Progress<'reporter>, StartError>
Validates configuration, samples enablement and emits Started when enabled.