pub struct TerminalError { /* private fields */ }Expand description
Terminal emission failure paired with elapsed operation time.
Implementations
Sourceimpl TerminalError
impl TerminalError
Sourcepub const fn emission_error(&self) -> &EmissionError
pub const fn emission_error(&self) -> &EmissionError
Returns the emission failure.
Sourcepub fn into_emission_error(self) -> EmissionError
pub fn into_emission_error(self) -> EmissionError
Consumes the terminal error and returns its emission failure.
Sourcepub fn into_parts(self) -> (Duration, EmissionError)
pub fn into_parts(self) -> (Duration, EmissionError)
Consumes the terminal error and returns elapsed time and failure.