pub struct WorkerPanic { /* private fields */ }Expand description
An opaque panic payload captured from an automatic reporter worker.
Implementations
Sourceimpl WorkerPanic
impl WorkerPanic
Sourcepub fn message(&self) -> Option<&str>
pub fn message(&self) -> Option<&str>
Returns a borrowed message for standard string panic payloads.
Sourcepub fn into_payload(self) -> Box<dyn Any + Send + 'static>
pub fn into_payload(self) -> Box<dyn Any + Send + 'static>
Consumes the error and returns the original panic payload.
Sourcepub fn resume_unwind(self) -> !
pub fn resume_unwind(self) -> !
Resumes unwinding with the original panic payload.