Generic progress reporting data model and reporter abstractions.
This crate models progress as immutable events carrying lifecycle phase, optional stage information, counters, and timing.
Generic progress reporting data model and reporter abstractions.
This crate models progress as immutable events carrying lifecycle phase, optional stage information, counters, and timing.