Progress reporter trait and built-in implementations.
Re-exports
pub use format::HumanReadableMetricSnapshotFormatter;pub use format::JsonMetricSnapshotFormatter;pub use format::MetricSnapshotFormatter;
Modules
- format
- Formatting support for progress metric snapshots.
Structs
- Formatted
Progress Reporter - Progress reporter that formats each metric snapshot and sends it to a consumer.
- Human
Readable Progress Reporter - Progress reporter that emits human-readable strings to a consumer.
- Json
Logger Progress Reporter - Progress reporter that emits JSON metric snapshots through
log. - Json
Progress Reporter - Progress reporter that emits JSON metric snapshot strings to a consumer.
- Json
Stderr Progress Reporter - Progress reporter that writes JSON metric snapshots to stderr.
- Json
Stdout Progress Reporter - Progress reporter that writes JSON metric snapshots to stdout.
- Json
Writer Progress Reporter - Progress reporter that writes JSON metric snapshots to a writer.
- Logger
Progress Reporter - Progress reporter that emits human-readable metric snapshots through
log. - Metric
Snapshot Progress Reporter - Progress reporter that sends metric snapshot objects to a consumer.
- NoOp
Progress Reporter - Progress reporter that ignores all events.
- Stderr
Progress Reporter - Progress reporter that writes human-readable metric snapshots to stderr.
- Stdout
Progress Reporter - Progress reporter that writes human-readable metric snapshots to stdout.
- Writer
Progress Reporter - Progress reporter that writes human-readable metric snapshots to a writer.
Traits
- Progress
Reporter - Receives immutable progress events for one logical operation.